@@ -591,3 +591,9 @@ class CreateContainerGroupRequest(RpcRequest):
 	def set_SpotPriceLimit(self, SpotPriceLimit):
 		self.add_query_param('SpotPriceLimit', SpotPriceLimit)
 
+	def get_EphemeralStorage(self):
+		return self.get_query_params().get('EphemeralStorage')
+
+	def set_EphemeralStorage(self, EphemeralStorage):
+		self.add_query_param('EphemeralStorage', EphemeralStorage)
+
